@@ -1,5 +1,10 @@
-formatXY <-
-function(x){
+#### Function formatXY as part of R package phylotools
+#### By Jinlong Zhang  <Jinlongzhang01@gmail.com>
+#### Institute of Botany, the Chinese Academy of Sciences, Beijing ,China
+#### Nov- 01-2010
+
+
+formatXY <- function(x){
     ncharX <- substring(x, 2, regexpr("Y", x)-1)
     ncharY <- substring(x, nchar(ncharX)+3, nchar(x))
     resX <- c()
