@@ -1,10 +1,9 @@
 #### Function framsub as part of R package phylotools
 #### By Jinlong Zhang  <Jinlongzhang01@gmail.com>
 #### Institute of Botany, the Chinese Academy of Sciences, Beijing ,China
-#### Nov- 01-2011
+#### Nov- 01-2010
 
-framsub <-
-function(x, pattern = "-", replacement = "?"){
+framsub <- function(x, pattern = "-", replacement = "?"){
      result <- rep(NA, 2 * nrow(x))
      dim(result) <- c(nrow(x),2)
      for(i in 1:nrow(x)){
