@@ -1,5 +1,10 @@
-inequality <-
-function(tree, subtree, h, detail = FALSE)
+#### Function inequality as part of R package phylotools
+#### By Jinlong Zhang  <Jinlongzhang01@gmail.com>
+#### Institute of Botany, the Chinese Academy of Sciences, Beijing ,China
+#### Nov- 01-2010
+
+
+inequality <- function(tree, subtree, h, detail = FALSE)
 {
     a <- tree$tip.label
     b <- subtree$tip.label
